# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planning_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.planning.proto import open_space_task_config_pb2 as modules_dot_planning_dot_proto_dot_open__space__task__config__pb2
from modules.planning.proto import task_config_pb2 as modules_dot_planning_dot_proto_dot_task__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planning_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,modules/planning/proto/planning_config.proto\x12\x0f\x61pollo.planning\x1a\x33modules/planning/proto/open_space_task_config.proto\x1a(modules/planning/proto/task_config.proto\"\xdd\x16\n\nTaskConfig\x12\x37\n\ttask_type\x18\x01 \x01(\x0e\x32$.apollo.planning.TaskConfig.TaskType\x12\x43\n\x14\x63reep_decider_config\x18\x02 \x01(\x0b\x32#.apollo.planning.CreepDeciderConfigH\x00\x12N\n\x1alane_change_decider_config\x18\x03 \x01(\x0b\x32(.apollo.planning.LaneChangeDeciderConfigH\x00\x12]\n\"open_space_fallback_decider_config\x18\x04 \x01(\x0b\x32/.apollo.planning.OpenSpaceFallBackDeciderConfigH\x00\x12\\\n\"open_space_pre_stop_decider_config\x18\x05 \x01(\x0b\x32..apollo.planning.OpenSpacePreStopDeciderConfigH\x00\x12S\n\x1dopen_space_roi_decider_config\x18\x06 \x01(\x0b\x32*.apollo.planning.OpenSpaceRoiDeciderConfigH\x00\x12V\n\x1epath_assessment_decider_config\x18\x07 \x01(\x0b\x32,.apollo.planning.PathAssessmentDeciderConfigH\x00\x12N\n\x1apath_bounds_decider_config\x18\x08 \x01(\x0b\x32(.apollo.planning.PathBoundsDeciderConfigH\x00\x12\x41\n\x13path_decider_config\x18\t \x01(\x0b\x32\".apollo.planning.PathDeciderConfigH\x00\x12W\n\x1fpath_lane_borrow_decider_config\x18\n \x01(\x0b\x32,.apollo.planning.PathLaneBorrowDeciderConfigH\x00\x12T\n\x1dpath_reference_decider_config\x18\x0b \x01(\x0b\x32+.apollo.planning.PathReferenceDeciderConfigH\x00\x12L\n\x19path_reuse_decider_config\x18\x0c \x01(\x0b\x32\'.apollo.planning.PathReuseDeciderConfigH\x00\x12U\n\x1erule_based_stop_decider_config\x18\r \x01(\x0b\x32+.apollo.planning.RuleBasedStopDeciderConfigH\x00\x12P\n\x1bspeed_bounds_decider_config\x18\x0e \x01(\x0b\x32).apollo.planning.SpeedBoundsDeciderConfigH\x00\x12J\n\x18st_bounds_decider_config\x18\x0f \x01(\x0b\x32&.apollo.planning.STBoundsDeciderConfigH\x00\x12\x65\n&open_space_trajectory_partition_config\x18\x10 \x01(\x0b\x32\x33.apollo.planning.OpenSpaceTrajectoryPartitionConfigH\x00\x12\x63\n%open_space_trajectory_provider_config\x18\x11 \x01(\x0b\x32\x32.apollo.planning.OpenSpaceTrajectoryProviderConfigH\x00\x12v\n/piecewise_jerk_nonlinear_speed_optimizer_config\x18\x12 \x01(\x0b\x32;.apollo.planning.PiecewiseJerkNonlinearSpeedOptimizerConfigH\x00\x12\x61\n$piecewise_jerk_path_optimizer_config\x18\x13 \x01(\x0b\x32\x31.apollo.planning.PiecewiseJerkPathOptimizerConfigH\x00\x12\x63\n%piecewise_jerk_speed_optimizer_config\x18\x14 \x01(\x0b\x32\x32.apollo.planning.PiecewiseJerkSpeedOptimizerConfigH\x00\x12Z\n speed_heuristic_optimizer_config\x18\x15 \x01(\x0b\x32..apollo.planning.SpeedHeuristicOptimizerConfigH\x00\x12\x61\n$learning_model_inference_task_config\x18\x16 \x01(\x0b\x32\x31.apollo.planning.LearningModelInferenceTaskConfigH\x00\x12v\n/learning_model_inference_trajectory_task_config\x18\x17 \x01(\x0b\x32;.apollo.planning.LearningModelInferenceTrajectoryTaskConfigH\x00\"\xbf\x06\n\x08TaskType\x12\x11\n\rCREEP_DECIDER\x10\x01\x12\x17\n\x13LANE_CHANGE_DECIDER\x10\x02\x12\x19\n\x15NAVI_OBSTACLE_DECIDER\x10\x03\x12\x15\n\x11NAVI_PATH_DECIDER\x10\x04\x12\x16\n\x12NAVI_SPEED_DECIDER\x10\x05\x12\x1f\n\x1bOPEN_SPACE_FALLBACK_DECIDER\x10\x06\x12\x1f\n\x1bOPEN_SPACE_PRE_STOP_DECIDER\x10\x07\x12\x1a\n\x16OPEN_SPACE_ROI_DECIDER\x10\x08\x12\x1b\n\x17PATH_ASSESSMENT_DECIDER\x10\t\x12\x17\n\x13PATH_BOUNDS_DECIDER\x10\n\x12\x10\n\x0cPATH_DECIDER\x10\x0b\x12\x1c\n\x18PATH_LANE_BORROW_DECIDER\x10\x0c\x12\x1a\n\x16PATH_REFERENCE_DECIDER\x10\r\x12\x16\n\x12PATH_REUSE_DECIDER\x10\x0e\x12\x0f\n\x0bRSS_DECIDER\x10\x0f\x12\x1b\n\x17RULE_BASED_STOP_DECIDER\x10\x10\x12\x1f\n\x1bSPEED_BOUNDS_PRIORI_DECIDER\x10\x11\x12\x1e\n\x1aSPEED_BOUNDS_FINAL_DECIDER\x10\x12\x12\x11\n\rSPEED_DECIDER\x10\x13\x12\x15\n\x11ST_BOUNDS_DECIDER\x10\x14\x12#\n\x1fOPEN_SPACE_TRAJECTORY_PARTITION\x10\x15\x12\"\n\x1eOPEN_SPACE_TRAJECTORY_PROVIDER\x10\x16\x12,\n(PIECEWISE_JERK_NONLINEAR_SPEED_OPTIMIZER\x10\x17\x12!\n\x1dPIECEWISE_JERK_PATH_OPTIMIZER\x10\x18\x12\"\n\x1ePIECEWISE_JERK_SPEED_OPTIMIZER\x10\x19\x12\x1d\n\x19SPEED_HEURISTIC_OPTIMIZER\x10\x1a\x12!\n\x1dLEARNING_MODEL_INFERENCE_TASK\x10\x1b\x12,\n(LEARNING_MODEL_INFERENCE_TRAJECTORY_TASK\x10\x1c\x42\r\n\x0btask_config\"\xa6\x02\n)ScenarioBareIntersectionUnprotectedConfig\x12\x35\n)start_bare_intersection_scenario_distance\x18\x01 \x01(\x01:\x02\x32\x35\x12#\n\x14\x65nable_explicit_stop\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x13min_pass_s_distance\x18\x03 \x01(\x01:\x01\x33\x12%\n\x15\x61pproach_cruise_speed\x18\x04 \x01(\x01:\x06\x36.7056\x12\x1a\n\rstop_distance\x18\x05 \x01(\x01:\x03\x30.5\x12\x1b\n\x10stop_timeout_sec\x18\x06 \x01(\x02:\x01\x38\x12\x1d\n\x11\x63reep_timeout_sec\x18\x07 \x01(\x02:\x02\x31\x30\"\xac\x01\n\x1fScenarioEmergencyPullOverConfig\x12 \n\x15max_stop_deceleration\x18\x01 \x01(\x01:\x01\x33\x12&\n\x1bslow_down_deceleration_time\x18\x02 \x01(\x01:\x01\x33\x12#\n\x16target_slow_down_speed\x18\x03 \x01(\x01:\x03\x32.5\x12\x1a\n\rstop_distance\x18\x04 \x01(\x01:\x03\x31.5\"Y\n\x1bScenarioEmergencyStopConfig\x12 \n\x15max_stop_deceleration\x18\x01 \x01(\x01:\x01\x36\x12\x18\n\rstop_distance\x18\x02 \x01(\x01:\x01\x31\"\x1a\n\x18ScenarioLaneFollowConfig\"#\n!ScenarioLearningModelSampleConfig\"!\n\x1fScenarioNarrowStreetUTurnConfig\"\xa7\x01\n\x17ScenarioParkAndGoConfig\x12 \n\x15\x66ront_obstacle_buffer\x18\x01 \x01(\x01:\x01\x34\x12\x1b\n\x0eheading_buffer\x18\x02 \x01(\x01:\x03\x30.5\x12\x1c\n\x10min_dist_to_dest\x18\x03 \x01(\x01:\x02\x32\x35\x12/\n#max_steering_percentage_when_cruise\x18\x04 \x01(\x01:\x02\x39\x30\"\xc1\x03\n\x16ScenarioPullOverConfig\x12-\n!start_pull_over_scenario_distance\x18\x01 \x01(\x01:\x02\x35\x30\x12)\n\x1dpull_over_min_distance_buffer\x18\x02 \x01(\x01:\x02\x31\x30\x12$\n\x18max_distance_stop_search\x18\x03 \x01(\x01:\x02\x32\x35\x12%\n\x18max_s_error_to_end_point\x18\x04 \x01(\x01:\x03\x30.2\x12%\n\x18max_l_error_to_end_point\x18\x05 \x01(\x01:\x03\x30.5\x12)\n\x1cmax_theta_error_to_end_point\x18\x06 \x01(\x01:\x03\x30.2\x12,\n\x1fmax_distance_error_to_end_point\x18\x07 \x01(\x01:\x03\x30.2\x12&\n\x1apass_destination_threshold\x18\x08 \x01(\x01:\x02\x31\x30\x12\"\n\x17max_valid_stop_distance\x18\t \x01(\x01:\x01\x31\x12\x34\n)s_distance_to_stop_for_open_space_parking\x18\n \x01(\x01:\x01\x37\"\xa3\x02\n!ScenarioStopSignUnprotectedConfig\x12,\n!start_stop_sign_scenario_distance\x18\x01 \x01(\x01:\x01\x35\x12\x30\n%watch_vehicle_max_valid_stop_distance\x18\x02 \x01(\x01:\x01\x35\x12$\n\x17max_valid_stop_distance\x18\x03 \x01(\x01:\x03\x33.5\x12\x1c\n\x11stop_duration_sec\x18\x04 \x01(\x02:\x01\x31\x12\x1e\n\x13min_pass_s_distance\x18\x05 \x01(\x01:\x01\x33\x12\x1b\n\x10stop_timeout_sec\x18\x06 \x01(\x02:\x01\x38\x12\x1d\n\x11\x63reep_timeout_sec\x18\x07 \x01(\x02:\x02\x31\x30\"\x9b\x01\n#ScenarioTrafficLightProtectedConfig\x12\x30\n%start_traffic_light_scenario_distance\x18\x01 \x01(\x01:\x01\x35\x12\"\n\x17max_valid_stop_distance\x18\x02 \x01(\x01:\x01\x32\x12\x1e\n\x13min_pass_s_distance\x18\x03 \x01(\x01:\x01\x33\"\x95\x02\n-ScenarioTrafficLightUnprotectedLeftTurnConfig\x12\x30\n%start_traffic_light_scenario_distance\x18\x01 \x01(\x01:\x01\x35\x12#\n\x15\x61pproach_cruise_speed\x18\x02 \x01(\x01:\x04\x32.78\x12$\n\x17max_valid_stop_distance\x18\x03 \x01(\x01:\x03\x33.5\x12\x1e\n\x13min_pass_s_distance\x18\x04 \x01(\x01:\x01\x33\x12\x1d\n\x11\x63reep_timeout_sec\x18\x05 \x01(\x02:\x02\x31\x30\x12(\n\x1amax_adc_speed_before_creep\x18\x06 \x01(\x01:\x04\x35.56\"\xca\x02\n.ScenarioTrafficLightUnprotectedRightTurnConfig\x12\x30\n%start_traffic_light_scenario_distance\x18\x01 \x01(\x01:\x01\x35\x12\'\n\x18\x65nable_right_turn_on_red\x18\x02 \x01(\x08:\x05\x66\x61lse\x12$\n\x17max_valid_stop_distance\x18\x03 \x01(\x01:\x03\x33.5\x12\x1e\n\x13min_pass_s_distance\x18\x04 \x01(\x01:\x01\x33\x12\x31\n&red_light_right_turn_stop_duration_sec\x18\x05 \x01(\x02:\x01\x33\x12\x1d\n\x11\x63reep_timeout_sec\x18\x06 \x01(\x02:\x02\x31\x30\x12%\n\x1amax_adc_speed_before_creep\x18\x07 \x01(\x01:\x01\x33\"i\n\x1aScenarioValetParkingConfig\x12\'\n\x1bparking_spot_range_to_start\x18\x01 \x01(\x01:\x02\x32\x30\x12\"\n\x17max_valid_stop_distance\x18\x02 \x01(\x01:\x01\x31\"\xae\x01\n\x17ScenarioYieldSignConfig\x12.\n\"start_yield_sign_scenario_distance\x18\x01 \x01(\x01:\x02\x31\x30\x12$\n\x17max_valid_stop_distance\x18\x02 \x01(\x01:\x03\x34.5\x12\x1e\n\x13min_pass_s_distance\x18\x03 \x01(\x01:\x01\x33\x12\x1d\n\x11\x63reep_timeout_sec\x18\x04 \x01(\x02:\x02\x31\x30\"\xf3\x19\n\x0eScenarioConfig\x12\x43\n\rscenario_type\x18\x01 \x01(\x0e\x32,.apollo.planning.ScenarioConfig.ScenarioType\x12G\n\x12lane_follow_config\x18\x02 \x01(\x0b\x32).apollo.planning.ScenarioLaneFollowConfigH\x00\x12j\n$bare_intersection_unprotected_config\x18\x03 \x01(\x0b\x32:.apollo.planning.ScenarioBareIntersectionUnprotectedConfigH\x00\x12V\n\x1a\x65mergency_pull_over_config\x18\x04 \x01(\x0b\x32\x30.apollo.planning.ScenarioEmergencyPullOverConfigH\x00\x12M\n\x15\x65mergency_stop_config\x18\x05 \x01(\x0b\x32,.apollo.planning.ScenarioEmergencyStopConfigH\x00\x12Z\n\x1clearning_model_sample_config\x18\x06 \x01(\x0b\x32\x32.apollo.planning.ScenarioLearningModelSampleConfigH\x00\x12W\n\x1bnarrow_street_u_turn_config\x18\x07 \x01(\x0b\x32\x30.apollo.planning.ScenarioNarrowStreetUTurnConfigH\x00\x12\x46\n\x12park_and_go_config\x18\x08 \x01(\x0b\x32(.apollo.planning.ScenarioParkAndGoConfigH\x00\x12\x43\n\x10pull_over_config\x18\t \x01(\x0b\x32\'.apollo.planning.ScenarioPullOverConfigH\x00\x12Z\n\x1cstop_sign_unprotected_config\x18\n \x01(\x0b\x32\x32.apollo.planning.ScenarioStopSignUnprotectedConfigH\x00\x12^\n\x1etraffic_light_protected_config\x18\x0b \x01(\x0b\x32\x34.apollo.planning.ScenarioTrafficLightProtectedConfigH\x00\x12t\n*traffic_light_unprotected_left_turn_config\x18\x0c \x01(\x0b\x32>.apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfigH\x00\x12v\n+traffic_light_unprotected_right_turn_config\x18\r \x01(\x0b\x32?.apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfigH\x00\x12K\n\x14valet_parking_config\x18\x0e \x01(\x0b\x32+.apollo.planning.ScenarioValetParkingConfigH\x00\x12\x45\n\x11yield_sign_config\x18\x0f \x01(\x0b\x32(.apollo.planning.ScenarioYieldSignConfigH\x00\x12=\n\nstage_type\x18\x10 \x03(\x0e\x32).apollo.planning.ScenarioConfig.StageType\x12\x41\n\x0cstage_config\x18\x11 \x03(\x0b\x32+.apollo.planning.ScenarioConfig.StageConfig\x1a\xce\x01\n\x0bStageConfig\x12=\n\nstage_type\x18\x01 \x01(\x0e\x32).apollo.planning.ScenarioConfig.StageType\x12\x15\n\x07\x65nabled\x18\x02 \x01(\x08:\x04true\x12\x37\n\ttask_type\x18\x03 \x03(\x0e\x32$.apollo.planning.TaskConfig.TaskType\x12\x30\n\x0btask_config\x18\x04 \x03(\x0b\x32\x1b.apollo.planning.TaskConfig\"\x8b\x03\n\x0cScenarioType\x12\x0f\n\x0bLANE_FOLLOW\x10\x00\x12!\n\x1d\x42\x41RE_INTERSECTION_UNPROTECTED\x10\x02\x12\x17\n\x13STOP_SIGN_PROTECTED\x10\x03\x12\x19\n\x15STOP_SIGN_UNPROTECTED\x10\x04\x12\x1b\n\x17TRAFFIC_LIGHT_PROTECTED\x10\x05\x12\'\n#TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN\x10\x06\x12(\n$TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN\x10\x07\x12\x0e\n\nYIELD_SIGN\x10\x08\x12\r\n\tPULL_OVER\x10\t\x12\x11\n\rVALET_PARKING\x10\n\x12\x17\n\x13\x45MERGENCY_PULL_OVER\x10\x0b\x12\x12\n\x0e\x45MERGENCY_STOP\x10\x0c\x12\x18\n\x14NARROW_STREET_U_TURN\x10\r\x12\x0f\n\x0bPARK_AND_GO\x10\x0e\x12\x19\n\x15LEARNING_MODEL_SAMPLE\x10\x0f\"\xcb\t\n\tStageType\x12\x0c\n\x08NO_STAGE\x10\x00\x12\x1d\n\x19LANE_FOLLOW_DEFAULT_STAGE\x10\x01\x12+\n&BARE_INTERSECTION_UNPROTECTED_APPROACH\x10\xc8\x01\x12\x36\n1BARE_INTERSECTION_UNPROTECTED_INTERSECTION_CRUISE\x10\xc9\x01\x12#\n\x1eSTOP_SIGN_UNPROTECTED_PRE_STOP\x10\xac\x02\x12\x1f\n\x1aSTOP_SIGN_UNPROTECTED_STOP\x10\xad\x02\x12 \n\x1bSTOP_SIGN_UNPROTECTED_CREEP\x10\xae\x02\x12.\n)STOP_SIGN_UNPROTECTED_INTERSECTION_CRUISE\x10\xaf\x02\x12%\n TRAFFIC_LIGHT_PROTECTED_APPROACH\x10\x90\x03\x12\x30\n+TRAFFIC_LIGHT_PROTECTED_INTERSECTION_CRUISE\x10\x91\x03\x12\x31\n,TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN_APPROACH\x10\x9a\x03\x12.\n)TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN_CREEP\x10\x9b\x03\x12<\n7TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN_INTERSECTION_CRUISE\x10\x9c\x03\x12.\n)TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN_STOP\x10\xa4\x03\x12/\n*TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN_CREEP\x10\xa5\x03\x12=\n8TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN_INTERSECTION_CRUISE\x10\xa6\x03\x12\x17\n\x12PULL_OVER_APPROACH\x10\xf4\x03\x12%\n PULL_OVER_RETRY_APPROACH_PARKING\x10\xf5\x03\x12\x1c\n\x17PULL_OVER_RETRY_PARKING\x10\xf6\x03\x12\"\n\x1d\x45MERGENCY_PULL_OVER_SLOW_DOWN\x10\xd8\x04\x12!\n\x1c\x45MERGENCY_PULL_OVER_APPROACH\x10\xd9\x04\x12 \n\x1b\x45MERGENCY_PULL_OVER_STANDBY\x10\xda\x04\x12\x1c\n\x17\x45MERGENCY_STOP_APPROACH\x10\xe2\x04\x12\x1b\n\x16\x45MERGENCY_STOP_STANDBY\x10\xe3\x04\x12+\n&VALET_PARKING_APPROACHING_PARKING_SPOT\x10\xbc\x05\x12\x1a\n\x15VALET_PARKING_PARKING\x10\xbd\x05\x12\x16\n\x11PARK_AND_GO_CHECK\x10\xa0\x06\x12\x17\n\x12PARK_AND_GO_CRUISE\x10\xa1\x06\x12\x17\n\x12PARK_AND_GO_ADJUST\x10\xa2\x06\x12\x1b\n\x16PARK_AND_GO_PRE_CRUISE\x10\xa3\x06\x12\x18\n\x13YIELD_SIGN_APPROACH\x10\x84\x07\x12\x15\n\x10YIELD_SIGN_CREEP\x10\x85\x07\x12\x17\n\x12LEARNING_MODEL_RUN\x10\xe8\x07\x42\x11\n\x0fscenario_config\"\x19\n\x17PlannerPublicRoadConfig\"\xaf\x02\n\x11PlannerNaviConfig\x12\x32\n\x04task\x18\x01 \x03(\x0e\x32$.apollo.planning.TaskConfig.TaskType\x12H\n\x18navi_path_decider_config\x18\x02 \x01(\x0b\x32&.apollo.planning.NaviPathDeciderConfig\x12J\n\x19navi_speed_decider_config\x18\x03 \x01(\x0b\x32\'.apollo.planning.NaviSpeedDeciderConfig\x12P\n\x1cnavi_obstacle_decider_config\x18\x04 \x01(\x0b\x32*.apollo.planning.NaviObstacleDeciderConfig\"G\n\x11RtkPlanningConfig\x12\x32\n\x0cplanner_type\x18\x01 \x01(\x0e\x32\x1c.apollo.planning.PlannerType\"\x9a\x01\n\x16StandardPlanningConfig\x12\x32\n\x0cplanner_type\x18\x01 \x03(\x0e\x32\x1c.apollo.planning.PlannerType\x12L\n\x1aplanner_public_road_config\x18\x02 \x01(\x0b\x32(.apollo.planning.PlannerPublicRoadConfig\"\x8f\x01\n\x18NavigationPlanningConfig\x12\x32\n\x0cplanner_type\x18\x01 \x03(\x0e\x32\x1c.apollo.planning.PlannerType\x12?\n\x13planner_navi_config\x18\x04 \x01(\x0b\x32\".apollo.planning.PlannerNaviConfig\"\xf8\x02\n\x0bTopicConfig\x12\x15\n\rchassis_topic\x18\x01 \x01(\t\x12\x18\n\x10hmi_status_topic\x18\x02 \x01(\t\x12\x1a\n\x12localization_topic\x18\x03 \x01(\t\x12\x1a\n\x12planning_pad_topic\x18\x04 \x01(\t\x12!\n\x19planning_trajectory_topic\x18\x05 \x01(\t\x12\x18\n\x10prediction_topic\x18\x06 \x01(\t\x12\x1a\n\x12relative_map_topic\x18\x07 \x01(\t\x12\x1d\n\x15routing_request_topic\x18\x08 \x01(\t\x12\x1e\n\x16routing_response_topic\x18\t \x01(\t\x12\x1b\n\x13story_telling_topic\x18\n \x01(\t\x12%\n\x1dtraffic_light_detection_topic\x18\x0b \x01(\t\x12$\n\x1cplanning_learning_data_topic\x18\x0c \x01(\t\"\xa9\x04\n\x0ePlanningConfig\x12\x32\n\x0ctopic_config\x18\x01 \x01(\x0b\x32\x1c.apollo.planning.TopicConfig\x12K\n\rlearning_mode\x18\x02 \x01(\x0e\x32\x34.apollo.planning.PlanningConfig.PlanningLearningMode\x12\x41\n\x13rtk_planning_config\x18\x03 \x01(\x0b\x32\".apollo.planning.RtkPlanningConfigH\x00\x12K\n\x18standard_planning_config\x18\x04 \x01(\x0b\x32\'.apollo.planning.StandardPlanningConfigH\x00\x12O\n\x1anavigation_planning_config\x18\x05 \x01(\x0b\x32).apollo.planning.NavigationPlanningConfigH\x00\x12\x38\n\x13\x64\x65\x66\x61ult_task_config\x18\x06 \x03(\x0b\x32\x1b.apollo.planning.TaskConfig\"h\n\x14PlanningLearningMode\x12\x0f\n\x0bNO_LEARNING\x10\x00\x12\x07\n\x03\x45\x32\x45\x10\x01\x12\n\n\x06HYBRID\x10\x02\x12\x0b\n\x07RL_TEST\x10\x03\x12\x0c\n\x08\x45\x32\x45_TEST\x10\x04\x12\x0f\n\x0bHYBRID_TEST\x10\x05\x42\x11\n\x0fplanning_config*>\n\x0bPlannerType\x12\x07\n\x03RTK\x10\x00\x12\x0f\n\x0bPUBLIC_ROAD\x10\x01\x12\x08\n\x04NAVI\x10\x02\x12\x0b\n\x07LATTICE\x10\x03'
  ,
  dependencies=[modules_dot_planning_dot_proto_dot_open__space__task__config__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_task__config__pb2.DESCRIPTOR,])

_PLANNERTYPE = _descriptor.EnumDescriptor(
  name='PlannerType',
  full_name='apollo.planning.PlannerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RTK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_ROAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAVI', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LATTICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10668,
  serialized_end=10730,
)
_sym_db.RegisterEnumDescriptor(_PLANNERTYPE)

PlannerType = enum_type_wrapper.EnumTypeWrapper(_PLANNERTYPE)
RTK = 0
PUBLIC_ROAD = 1
NAVI = 2
LATTICE = 3


_TASKCONFIG_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='apollo.planning.TaskConfig.TaskType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREEP_DECIDER', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_CHANGE_DECIDER', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAVI_OBSTACLE_DECIDER', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAVI_PATH_DECIDER', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAVI_SPEED_DECIDER', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_SPACE_FALLBACK_DECIDER', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_SPACE_PRE_STOP_DECIDER', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_SPACE_ROI_DECIDER', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_ASSESSMENT_DECIDER', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_BOUNDS_DECIDER', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_DECIDER', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_LANE_BORROW_DECIDER', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_REFERENCE_DECIDER', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_REUSE_DECIDER', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSS_DECIDER', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RULE_BASED_STOP_DECIDER', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED_BOUNDS_PRIORI_DECIDER', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED_BOUNDS_FINAL_DECIDER', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED_DECIDER', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BOUNDS_DECIDER', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_SPACE_TRAJECTORY_PARTITION', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_SPACE_TRAJECTORY_PROVIDER', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PIECEWISE_JERK_NONLINEAR_SPEED_OPTIMIZER', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PIECEWISE_JERK_PATH_OPTIMIZER', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PIECEWISE_JERK_SPEED_OPTIMIZER', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED_HEURISTIC_OPTIMIZER', index=25, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEARNING_MODEL_INFERENCE_TASK', index=26, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEARNING_MODEL_INFERENCE_TRAJECTORY_TASK', index=27, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2224,
  serialized_end=3055,
)
_sym_db.RegisterEnumDescriptor(_TASKCONFIG_TASKTYPE)

_SCENARIOCONFIG_SCENARIOTYPE = _descriptor.EnumDescriptor(
  name='ScenarioType',
  full_name='apollo.planning.ScenarioConfig.ScenarioType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANE_FOLLOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARE_INTERSECTION_UNPROTECTED', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN_PROTECTED', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN_UNPROTECTED', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_PROTECTED', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD_SIGN', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALET_PARKING', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PULL_OVER', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_STOP', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_STREET_U_TURN', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEARNING_MODEL_SAMPLE', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7378,
  serialized_end=7773,
)
_sym_db.RegisterEnumDescriptor(_SCENARIOCONFIG_SCENARIOTYPE)

_SCENARIOCONFIG_STAGETYPE = _descriptor.EnumDescriptor(
  name='StageType',
  full_name='apollo.planning.ScenarioConfig.StageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_STAGE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_FOLLOW_DEFAULT_STAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARE_INTERSECTION_UNPROTECTED_APPROACH', index=2, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARE_INTERSECTION_UNPROTECTED_INTERSECTION_CRUISE', index=3, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN_UNPROTECTED_PRE_STOP', index=4, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN_UNPROTECTED_STOP', index=5, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN_UNPROTECTED_CREEP', index=6, number=302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN_UNPROTECTED_INTERSECTION_CRUISE', index=7, number=303,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_PROTECTED_APPROACH', index=8, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_PROTECTED_INTERSECTION_CRUISE', index=9, number=401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN_APPROACH', index=10, number=410,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN_CREEP', index=11, number=411,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_LEFT_TURN_INTERSECTION_CRUISE', index=12, number=412,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN_STOP', index=13, number=420,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN_CREEP', index=14, number=421,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT_UNPROTECTED_RIGHT_TURN_INTERSECTION_CRUISE', index=15, number=422,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER_APPROACH', index=16, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER_RETRY_APPROACH_PARKING', index=17, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL_OVER_RETRY_PARKING', index=18, number=502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PULL_OVER_SLOW_DOWN', index=19, number=600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PULL_OVER_APPROACH', index=20, number=601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PULL_OVER_STANDBY', index=21, number=602,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_STOP_APPROACH', index=22, number=610,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_STOP_STANDBY', index=23, number=611,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALET_PARKING_APPROACHING_PARKING_SPOT', index=24, number=700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALET_PARKING_PARKING', index=25, number=701,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO_CHECK', index=26, number=800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO_CRUISE', index=27, number=801,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO_ADJUST', index=28, number=802,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK_AND_GO_PRE_CRUISE', index=29, number=803,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD_SIGN_APPROACH', index=30, number=900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD_SIGN_CREEP', index=31, number=901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEARNING_MODEL_RUN', index=32, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7776,
  serialized_end=9003,
)
_sym_db.RegisterEnumDescriptor(_SCENARIOCONFIG_STAGETYPE)

_PLANNINGCONFIG_PLANNINGLEARNINGMODE = _descriptor.EnumDescriptor(
  name='PlanningLearningMode',
  full_name='apollo.planning.PlanningConfig.PlanningLearningMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_LEARNING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='E2E', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYBRID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RL_TEST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='E2E_TEST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYBRID_TEST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10543,
  serialized_end=10647,
)
_sym_db.RegisterEnumDescriptor(_PLANNINGCONFIG_PLANNINGLEARNINGMODE)


_TASKCONFIG = _descriptor.Descriptor(
  name='TaskConfig',
  full_name='apollo.planning.TaskConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='apollo.planning.TaskConfig.task_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_decider_config', full_name='apollo.planning.TaskConfig.creep_decider_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_change_decider_config', full_name='apollo.planning.TaskConfig.lane_change_decider_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_fallback_decider_config', full_name='apollo.planning.TaskConfig.open_space_fallback_decider_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_pre_stop_decider_config', full_name='apollo.planning.TaskConfig.open_space_pre_stop_decider_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_roi_decider_config', full_name='apollo.planning.TaskConfig.open_space_roi_decider_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_assessment_decider_config', full_name='apollo.planning.TaskConfig.path_assessment_decider_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_bounds_decider_config', full_name='apollo.planning.TaskConfig.path_bounds_decider_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_decider_config', full_name='apollo.planning.TaskConfig.path_decider_config', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_lane_borrow_decider_config', full_name='apollo.planning.TaskConfig.path_lane_borrow_decider_config', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_reference_decider_config', full_name='apollo.planning.TaskConfig.path_reference_decider_config', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_reuse_decider_config', full_name='apollo.planning.TaskConfig.path_reuse_decider_config', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule_based_stop_decider_config', full_name='apollo.planning.TaskConfig.rule_based_stop_decider_config', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_bounds_decider_config', full_name='apollo.planning.TaskConfig.speed_bounds_decider_config', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_bounds_decider_config', full_name='apollo.planning.TaskConfig.st_bounds_decider_config', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_trajectory_partition_config', full_name='apollo.planning.TaskConfig.open_space_trajectory_partition_config', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open_space_trajectory_provider_config', full_name='apollo.planning.TaskConfig.open_space_trajectory_provider_config', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piecewise_jerk_nonlinear_speed_optimizer_config', full_name='apollo.planning.TaskConfig.piecewise_jerk_nonlinear_speed_optimizer_config', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piecewise_jerk_path_optimizer_config', full_name='apollo.planning.TaskConfig.piecewise_jerk_path_optimizer_config', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piecewise_jerk_speed_optimizer_config', full_name='apollo.planning.TaskConfig.piecewise_jerk_speed_optimizer_config', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_heuristic_optimizer_config', full_name='apollo.planning.TaskConfig.speed_heuristic_optimizer_config', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_model_inference_task_config', full_name='apollo.planning.TaskConfig.learning_model_inference_task_config', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_model_inference_trajectory_task_config', full_name='apollo.planning.TaskConfig.learning_model_inference_trajectory_task_config', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TASKCONFIG_TASKTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task_config', full_name='apollo.planning.TaskConfig.task_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=161,
  serialized_end=3070,
)


_SCENARIOBAREINTERSECTIONUNPROTECTEDCONFIG = _descriptor.Descriptor(
  name='ScenarioBareIntersectionUnprotectedConfig',
  full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_bare_intersection_scenario_distance', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.start_bare_intersection_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_explicit_stop', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.enable_explicit_stop', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.min_pass_s_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approach_cruise_speed', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.approach_cruise_speed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(6.7056),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.stop_distance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_timeout_sec', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.stop_timeout_sec', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_timeout_sec', full_name='apollo.planning.ScenarioBareIntersectionUnprotectedConfig.creep_timeout_sec', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3073,
  serialized_end=3367,
)


_SCENARIOEMERGENCYPULLOVERCONFIG = _descriptor.Descriptor(
  name='ScenarioEmergencyPullOverConfig',
  full_name='apollo.planning.ScenarioEmergencyPullOverConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_stop_deceleration', full_name='apollo.planning.ScenarioEmergencyPullOverConfig.max_stop_deceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_down_deceleration_time', full_name='apollo.planning.ScenarioEmergencyPullOverConfig.slow_down_deceleration_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_slow_down_speed', full_name='apollo.planning.ScenarioEmergencyPullOverConfig.target_slow_down_speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.ScenarioEmergencyPullOverConfig.stop_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3370,
  serialized_end=3542,
)


_SCENARIOEMERGENCYSTOPCONFIG = _descriptor.Descriptor(
  name='ScenarioEmergencyStopConfig',
  full_name='apollo.planning.ScenarioEmergencyStopConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_stop_deceleration', full_name='apollo.planning.ScenarioEmergencyStopConfig.max_stop_deceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(6),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.ScenarioEmergencyStopConfig.stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3544,
  serialized_end=3633,
)


_SCENARIOLANEFOLLOWCONFIG = _descriptor.Descriptor(
  name='ScenarioLaneFollowConfig',
  full_name='apollo.planning.ScenarioLaneFollowConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3635,
  serialized_end=3661,
)


_SCENARIOLEARNINGMODELSAMPLECONFIG = _descriptor.Descriptor(
  name='ScenarioLearningModelSampleConfig',
  full_name='apollo.planning.ScenarioLearningModelSampleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3663,
  serialized_end=3698,
)


_SCENARIONARROWSTREETUTURNCONFIG = _descriptor.Descriptor(
  name='ScenarioNarrowStreetUTurnConfig',
  full_name='apollo.planning.ScenarioNarrowStreetUTurnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3700,
  serialized_end=3733,
)


_SCENARIOPARKANDGOCONFIG = _descriptor.Descriptor(
  name='ScenarioParkAndGoConfig',
  full_name='apollo.planning.ScenarioParkAndGoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='front_obstacle_buffer', full_name='apollo.planning.ScenarioParkAndGoConfig.front_obstacle_buffer', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_buffer', full_name='apollo.planning.ScenarioParkAndGoConfig.heading_buffer', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_dist_to_dest', full_name='apollo.planning.ScenarioParkAndGoConfig.min_dist_to_dest', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_steering_percentage_when_cruise', full_name='apollo.planning.ScenarioParkAndGoConfig.max_steering_percentage_when_cruise', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(90),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3736,
  serialized_end=3903,
)


_SCENARIOPULLOVERCONFIG = _descriptor.Descriptor(
  name='ScenarioPullOverConfig',
  full_name='apollo.planning.ScenarioPullOverConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_pull_over_scenario_distance', full_name='apollo.planning.ScenarioPullOverConfig.start_pull_over_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(50),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_min_distance_buffer', full_name='apollo.planning.ScenarioPullOverConfig.pull_over_min_distance_buffer', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_distance_stop_search', full_name='apollo.planning.ScenarioPullOverConfig.max_distance_stop_search', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_s_error_to_end_point', full_name='apollo.planning.ScenarioPullOverConfig.max_s_error_to_end_point', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_l_error_to_end_point', full_name='apollo.planning.ScenarioPullOverConfig.max_l_error_to_end_point', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_theta_error_to_end_point', full_name='apollo.planning.ScenarioPullOverConfig.max_theta_error_to_end_point', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_distance_error_to_end_point', full_name='apollo.planning.ScenarioPullOverConfig.max_distance_error_to_end_point', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_destination_threshold', full_name='apollo.planning.ScenarioPullOverConfig.pass_destination_threshold', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioPullOverConfig.max_valid_stop_distance', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_distance_to_stop_for_open_space_parking', full_name='apollo.planning.ScenarioPullOverConfig.s_distance_to_stop_for_open_space_parking', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3906,
  serialized_end=4355,
)


_SCENARIOSTOPSIGNUNPROTECTEDCONFIG = _descriptor.Descriptor(
  name='ScenarioStopSignUnprotectedConfig',
  full_name='apollo.planning.ScenarioStopSignUnprotectedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_stop_sign_scenario_distance', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.start_stop_sign_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch_vehicle_max_valid_stop_distance', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.watch_vehicle_max_valid_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.max_valid_stop_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_duration_sec', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.stop_duration_sec', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.min_pass_s_distance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_timeout_sec', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.stop_timeout_sec', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_timeout_sec', full_name='apollo.planning.ScenarioStopSignUnprotectedConfig.creep_timeout_sec', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4358,
  serialized_end=4649,
)


_SCENARIOTRAFFICLIGHTPROTECTEDCONFIG = _descriptor.Descriptor(
  name='ScenarioTrafficLightProtectedConfig',
  full_name='apollo.planning.ScenarioTrafficLightProtectedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_traffic_light_scenario_distance', full_name='apollo.planning.ScenarioTrafficLightProtectedConfig.start_traffic_light_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioTrafficLightProtectedConfig.max_valid_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.ScenarioTrafficLightProtectedConfig.min_pass_s_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4652,
  serialized_end=4807,
)


_SCENARIOTRAFFICLIGHTUNPROTECTEDLEFTTURNCONFIG = _descriptor.Descriptor(
  name='ScenarioTrafficLightUnprotectedLeftTurnConfig',
  full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_traffic_light_scenario_distance', full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig.start_traffic_light_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approach_cruise_speed', full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig.approach_cruise_speed', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.78),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig.max_valid_stop_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig.min_pass_s_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_timeout_sec', full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig.creep_timeout_sec', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_adc_speed_before_creep', full_name='apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig.max_adc_speed_before_creep', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5.56),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4810,
  serialized_end=5087,
)


_SCENARIOTRAFFICLIGHTUNPROTECTEDRIGHTTURNCONFIG = _descriptor.Descriptor(
  name='ScenarioTrafficLightUnprotectedRightTurnConfig',
  full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_traffic_light_scenario_distance', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.start_traffic_light_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_right_turn_on_red', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.enable_right_turn_on_red', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.max_valid_stop_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.min_pass_s_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='red_light_right_turn_stop_duration_sec', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.red_light_right_turn_stop_duration_sec', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_timeout_sec', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.creep_timeout_sec', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_adc_speed_before_creep', full_name='apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig.max_adc_speed_before_creep', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5090,
  serialized_end=5420,
)


_SCENARIOVALETPARKINGCONFIG = _descriptor.Descriptor(
  name='ScenarioValetParkingConfig',
  full_name='apollo.planning.ScenarioValetParkingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parking_spot_range_to_start', full_name='apollo.planning.ScenarioValetParkingConfig.parking_spot_range_to_start', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(20),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioValetParkingConfig.max_valid_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5422,
  serialized_end=5527,
)


_SCENARIOYIELDSIGNCONFIG = _descriptor.Descriptor(
  name='ScenarioYieldSignConfig',
  full_name='apollo.planning.ScenarioYieldSignConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_yield_sign_scenario_distance', full_name='apollo.planning.ScenarioYieldSignConfig.start_yield_sign_scenario_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.ScenarioYieldSignConfig.max_valid_stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.ScenarioYieldSignConfig.min_pass_s_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creep_timeout_sec', full_name='apollo.planning.ScenarioYieldSignConfig.creep_timeout_sec', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5530,
  serialized_end=5704,
)


_SCENARIOCONFIG_STAGECONFIG = _descriptor.Descriptor(
  name='StageConfig',
  full_name='apollo.planning.ScenarioConfig.StageConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stage_type', full_name='apollo.planning.ScenarioConfig.StageConfig.stage_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.planning.ScenarioConfig.StageConfig.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='apollo.planning.ScenarioConfig.StageConfig.task_type', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_config', full_name='apollo.planning.ScenarioConfig.StageConfig.task_config', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7169,
  serialized_end=7375,
)

_SCENARIOCONFIG = _descriptor.Descriptor(
  name='ScenarioConfig',
  full_name='apollo.planning.ScenarioConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scenario_type', full_name='apollo.planning.ScenarioConfig.scenario_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_follow_config', full_name='apollo.planning.ScenarioConfig.lane_follow_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bare_intersection_unprotected_config', full_name='apollo.planning.ScenarioConfig.bare_intersection_unprotected_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergency_pull_over_config', full_name='apollo.planning.ScenarioConfig.emergency_pull_over_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergency_stop_config', full_name='apollo.planning.ScenarioConfig.emergency_stop_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_model_sample_config', full_name='apollo.planning.ScenarioConfig.learning_model_sample_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='narrow_street_u_turn_config', full_name='apollo.planning.ScenarioConfig.narrow_street_u_turn_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park_and_go_config', full_name='apollo.planning.ScenarioConfig.park_and_go_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_config', full_name='apollo.planning.ScenarioConfig.pull_over_config', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign_unprotected_config', full_name='apollo.planning.ScenarioConfig.stop_sign_unprotected_config', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_protected_config', full_name='apollo.planning.ScenarioConfig.traffic_light_protected_config', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_unprotected_left_turn_config', full_name='apollo.planning.ScenarioConfig.traffic_light_unprotected_left_turn_config', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_unprotected_right_turn_config', full_name='apollo.planning.ScenarioConfig.traffic_light_unprotected_right_turn_config', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valet_parking_config', full_name='apollo.planning.ScenarioConfig.valet_parking_config', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_sign_config', full_name='apollo.planning.ScenarioConfig.yield_sign_config', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage_type', full_name='apollo.planning.ScenarioConfig.stage_type', index=15,
      number=16, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage_config', full_name='apollo.planning.ScenarioConfig.stage_config', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCENARIOCONFIG_STAGECONFIG, ],
  enum_types=[
    _SCENARIOCONFIG_SCENARIOTYPE,
    _SCENARIOCONFIG_STAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scenario_config', full_name='apollo.planning.ScenarioConfig.scenario_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5707,
  serialized_end=9022,
)


_PLANNERPUBLICROADCONFIG = _descriptor.Descriptor(
  name='PlannerPublicRoadConfig',
  full_name='apollo.planning.PlannerPublicRoadConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9024,
  serialized_end=9049,
)


_PLANNERNAVICONFIG = _descriptor.Descriptor(
  name='PlannerNaviConfig',
  full_name='apollo.planning.PlannerNaviConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='apollo.planning.PlannerNaviConfig.task', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navi_path_decider_config', full_name='apollo.planning.PlannerNaviConfig.navi_path_decider_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navi_speed_decider_config', full_name='apollo.planning.PlannerNaviConfig.navi_speed_decider_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navi_obstacle_decider_config', full_name='apollo.planning.PlannerNaviConfig.navi_obstacle_decider_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9052,
  serialized_end=9355,
)


_RTKPLANNINGCONFIG = _descriptor.Descriptor(
  name='RtkPlanningConfig',
  full_name='apollo.planning.RtkPlanningConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='planner_type', full_name='apollo.planning.RtkPlanningConfig.planner_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9357,
  serialized_end=9428,
)


_STANDARDPLANNINGCONFIG = _descriptor.Descriptor(
  name='StandardPlanningConfig',
  full_name='apollo.planning.StandardPlanningConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='planner_type', full_name='apollo.planning.StandardPlanningConfig.planner_type', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planner_public_road_config', full_name='apollo.planning.StandardPlanningConfig.planner_public_road_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9431,
  serialized_end=9585,
)


_NAVIGATIONPLANNINGCONFIG = _descriptor.Descriptor(
  name='NavigationPlanningConfig',
  full_name='apollo.planning.NavigationPlanningConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='planner_type', full_name='apollo.planning.NavigationPlanningConfig.planner_type', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planner_navi_config', full_name='apollo.planning.NavigationPlanningConfig.planner_navi_config', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9588,
  serialized_end=9731,
)


_TOPICCONFIG = _descriptor.Descriptor(
  name='TopicConfig',
  full_name='apollo.planning.TopicConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chassis_topic', full_name='apollo.planning.TopicConfig.chassis_topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hmi_status_topic', full_name='apollo.planning.TopicConfig.hmi_status_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization_topic', full_name='apollo.planning.TopicConfig.localization_topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_pad_topic', full_name='apollo.planning.TopicConfig.planning_pad_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_trajectory_topic', full_name='apollo.planning.TopicConfig.planning_trajectory_topic', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction_topic', full_name='apollo.planning.TopicConfig.prediction_topic', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_map_topic', full_name='apollo.planning.TopicConfig.relative_map_topic', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_request_topic', full_name='apollo.planning.TopicConfig.routing_request_topic', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_response_topic', full_name='apollo.planning.TopicConfig.routing_response_topic', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='story_telling_topic', full_name='apollo.planning.TopicConfig.story_telling_topic', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_detection_topic', full_name='apollo.planning.TopicConfig.traffic_light_detection_topic', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_learning_data_topic', full_name='apollo.planning.TopicConfig.planning_learning_data_topic', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9734,
  serialized_end=10110,
)


_PLANNINGCONFIG = _descriptor.Descriptor(
  name='PlanningConfig',
  full_name='apollo.planning.PlanningConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_config', full_name='apollo.planning.PlanningConfig.topic_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='learning_mode', full_name='apollo.planning.PlanningConfig.learning_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtk_planning_config', full_name='apollo.planning.PlanningConfig.rtk_planning_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standard_planning_config', full_name='apollo.planning.PlanningConfig.standard_planning_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navigation_planning_config', full_name='apollo.planning.PlanningConfig.navigation_planning_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_task_config', full_name='apollo.planning.PlanningConfig.default_task_config', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLANNINGCONFIG_PLANNINGLEARNINGMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='planning_config', full_name='apollo.planning.PlanningConfig.planning_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10113,
  serialized_end=10666,
)

_TASKCONFIG.fields_by_name['task_type'].enum_type = _TASKCONFIG_TASKTYPE
_TASKCONFIG.fields_by_name['creep_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._CREEPDECIDERCONFIG
_TASKCONFIG.fields_by_name['lane_change_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._LANECHANGEDECIDERCONFIG
_TASKCONFIG.fields_by_name['open_space_fallback_decider_config'].message_type = modules_dot_planning_dot_proto_dot_open__space__task__config__pb2._OPENSPACEFALLBACKDECIDERCONFIG
_TASKCONFIG.fields_by_name['open_space_pre_stop_decider_config'].message_type = modules_dot_planning_dot_proto_dot_open__space__task__config__pb2._OPENSPACEPRESTOPDECIDERCONFIG
_TASKCONFIG.fields_by_name['open_space_roi_decider_config'].message_type = modules_dot_planning_dot_proto_dot_open__space__task__config__pb2._OPENSPACEROIDECIDERCONFIG
_TASKCONFIG.fields_by_name['path_assessment_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PATHASSESSMENTDECIDERCONFIG
_TASKCONFIG.fields_by_name['path_bounds_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PATHBOUNDSDECIDERCONFIG
_TASKCONFIG.fields_by_name['path_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PATHDECIDERCONFIG
_TASKCONFIG.fields_by_name['path_lane_borrow_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PATHLANEBORROWDECIDERCONFIG
_TASKCONFIG.fields_by_name['path_reference_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PATHREFERENCEDECIDERCONFIG
_TASKCONFIG.fields_by_name['path_reuse_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PATHREUSEDECIDERCONFIG
_TASKCONFIG.fields_by_name['rule_based_stop_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._RULEBASEDSTOPDECIDERCONFIG
_TASKCONFIG.fields_by_name['speed_bounds_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._SPEEDBOUNDSDECIDERCONFIG
_TASKCONFIG.fields_by_name['st_bounds_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._STBOUNDSDECIDERCONFIG
_TASKCONFIG.fields_by_name['open_space_trajectory_partition_config'].message_type = modules_dot_planning_dot_proto_dot_open__space__task__config__pb2._OPENSPACETRAJECTORYPARTITIONCONFIG
_TASKCONFIG.fields_by_name['open_space_trajectory_provider_config'].message_type = modules_dot_planning_dot_proto_dot_open__space__task__config__pb2._OPENSPACETRAJECTORYPROVIDERCONFIG
_TASKCONFIG.fields_by_name['piecewise_jerk_nonlinear_speed_optimizer_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PIECEWISEJERKNONLINEARSPEEDOPTIMIZERCONFIG
_TASKCONFIG.fields_by_name['piecewise_jerk_path_optimizer_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PIECEWISEJERKPATHOPTIMIZERCONFIG
_TASKCONFIG.fields_by_name['piecewise_jerk_speed_optimizer_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._PIECEWISEJERKSPEEDOPTIMIZERCONFIG
_TASKCONFIG.fields_by_name['speed_heuristic_optimizer_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._SPEEDHEURISTICOPTIMIZERCONFIG
_TASKCONFIG.fields_by_name['learning_model_inference_task_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._LEARNINGMODELINFERENCETASKCONFIG
_TASKCONFIG.fields_by_name['learning_model_inference_trajectory_task_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._LEARNINGMODELINFERENCETRAJECTORYTASKCONFIG
_TASKCONFIG_TASKTYPE.containing_type = _TASKCONFIG
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['creep_decider_config'])
_TASKCONFIG.fields_by_name['creep_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['lane_change_decider_config'])
_TASKCONFIG.fields_by_name['lane_change_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['open_space_fallback_decider_config'])
_TASKCONFIG.fields_by_name['open_space_fallback_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['open_space_pre_stop_decider_config'])
_TASKCONFIG.fields_by_name['open_space_pre_stop_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['open_space_roi_decider_config'])
_TASKCONFIG.fields_by_name['open_space_roi_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['path_assessment_decider_config'])
_TASKCONFIG.fields_by_name['path_assessment_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['path_bounds_decider_config'])
_TASKCONFIG.fields_by_name['path_bounds_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['path_decider_config'])
_TASKCONFIG.fields_by_name['path_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['path_lane_borrow_decider_config'])
_TASKCONFIG.fields_by_name['path_lane_borrow_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['path_reference_decider_config'])
_TASKCONFIG.fields_by_name['path_reference_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['path_reuse_decider_config'])
_TASKCONFIG.fields_by_name['path_reuse_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['rule_based_stop_decider_config'])
_TASKCONFIG.fields_by_name['rule_based_stop_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['speed_bounds_decider_config'])
_TASKCONFIG.fields_by_name['speed_bounds_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['st_bounds_decider_config'])
_TASKCONFIG.fields_by_name['st_bounds_decider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['open_space_trajectory_partition_config'])
_TASKCONFIG.fields_by_name['open_space_trajectory_partition_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['open_space_trajectory_provider_config'])
_TASKCONFIG.fields_by_name['open_space_trajectory_provider_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['piecewise_jerk_nonlinear_speed_optimizer_config'])
_TASKCONFIG.fields_by_name['piecewise_jerk_nonlinear_speed_optimizer_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['piecewise_jerk_path_optimizer_config'])
_TASKCONFIG.fields_by_name['piecewise_jerk_path_optimizer_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['piecewise_jerk_speed_optimizer_config'])
_TASKCONFIG.fields_by_name['piecewise_jerk_speed_optimizer_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['speed_heuristic_optimizer_config'])
_TASKCONFIG.fields_by_name['speed_heuristic_optimizer_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['learning_model_inference_task_config'])
_TASKCONFIG.fields_by_name['learning_model_inference_task_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_TASKCONFIG.oneofs_by_name['task_config'].fields.append(
  _TASKCONFIG.fields_by_name['learning_model_inference_trajectory_task_config'])
_TASKCONFIG.fields_by_name['learning_model_inference_trajectory_task_config'].containing_oneof = _TASKCONFIG.oneofs_by_name['task_config']
_SCENARIOCONFIG_STAGECONFIG.fields_by_name['stage_type'].enum_type = _SCENARIOCONFIG_STAGETYPE
_SCENARIOCONFIG_STAGECONFIG.fields_by_name['task_type'].enum_type = _TASKCONFIG_TASKTYPE
_SCENARIOCONFIG_STAGECONFIG.fields_by_name['task_config'].message_type = _TASKCONFIG
_SCENARIOCONFIG_STAGECONFIG.containing_type = _SCENARIOCONFIG
_SCENARIOCONFIG.fields_by_name['scenario_type'].enum_type = _SCENARIOCONFIG_SCENARIOTYPE
_SCENARIOCONFIG.fields_by_name['lane_follow_config'].message_type = _SCENARIOLANEFOLLOWCONFIG
_SCENARIOCONFIG.fields_by_name['bare_intersection_unprotected_config'].message_type = _SCENARIOBAREINTERSECTIONUNPROTECTEDCONFIG
_SCENARIOCONFIG.fields_by_name['emergency_pull_over_config'].message_type = _SCENARIOEMERGENCYPULLOVERCONFIG
_SCENARIOCONFIG.fields_by_name['emergency_stop_config'].message_type = _SCENARIOEMERGENCYSTOPCONFIG
_SCENARIOCONFIG.fields_by_name['learning_model_sample_config'].message_type = _SCENARIOLEARNINGMODELSAMPLECONFIG
_SCENARIOCONFIG.fields_by_name['narrow_street_u_turn_config'].message_type = _SCENARIONARROWSTREETUTURNCONFIG
_SCENARIOCONFIG.fields_by_name['park_and_go_config'].message_type = _SCENARIOPARKANDGOCONFIG
_SCENARIOCONFIG.fields_by_name['pull_over_config'].message_type = _SCENARIOPULLOVERCONFIG
_SCENARIOCONFIG.fields_by_name['stop_sign_unprotected_config'].message_type = _SCENARIOSTOPSIGNUNPROTECTEDCONFIG
_SCENARIOCONFIG.fields_by_name['traffic_light_protected_config'].message_type = _SCENARIOTRAFFICLIGHTPROTECTEDCONFIG
_SCENARIOCONFIG.fields_by_name['traffic_light_unprotected_left_turn_config'].message_type = _SCENARIOTRAFFICLIGHTUNPROTECTEDLEFTTURNCONFIG
_SCENARIOCONFIG.fields_by_name['traffic_light_unprotected_right_turn_config'].message_type = _SCENARIOTRAFFICLIGHTUNPROTECTEDRIGHTTURNCONFIG
_SCENARIOCONFIG.fields_by_name['valet_parking_config'].message_type = _SCENARIOVALETPARKINGCONFIG
_SCENARIOCONFIG.fields_by_name['yield_sign_config'].message_type = _SCENARIOYIELDSIGNCONFIG
_SCENARIOCONFIG.fields_by_name['stage_type'].enum_type = _SCENARIOCONFIG_STAGETYPE
_SCENARIOCONFIG.fields_by_name['stage_config'].message_type = _SCENARIOCONFIG_STAGECONFIG
_SCENARIOCONFIG_SCENARIOTYPE.containing_type = _SCENARIOCONFIG
_SCENARIOCONFIG_STAGETYPE.containing_type = _SCENARIOCONFIG
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['lane_follow_config'])
_SCENARIOCONFIG.fields_by_name['lane_follow_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['bare_intersection_unprotected_config'])
_SCENARIOCONFIG.fields_by_name['bare_intersection_unprotected_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['emergency_pull_over_config'])
_SCENARIOCONFIG.fields_by_name['emergency_pull_over_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['emergency_stop_config'])
_SCENARIOCONFIG.fields_by_name['emergency_stop_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['learning_model_sample_config'])
_SCENARIOCONFIG.fields_by_name['learning_model_sample_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['narrow_street_u_turn_config'])
_SCENARIOCONFIG.fields_by_name['narrow_street_u_turn_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['park_and_go_config'])
_SCENARIOCONFIG.fields_by_name['park_and_go_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['pull_over_config'])
_SCENARIOCONFIG.fields_by_name['pull_over_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['stop_sign_unprotected_config'])
_SCENARIOCONFIG.fields_by_name['stop_sign_unprotected_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['traffic_light_protected_config'])
_SCENARIOCONFIG.fields_by_name['traffic_light_protected_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['traffic_light_unprotected_left_turn_config'])
_SCENARIOCONFIG.fields_by_name['traffic_light_unprotected_left_turn_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['traffic_light_unprotected_right_turn_config'])
_SCENARIOCONFIG.fields_by_name['traffic_light_unprotected_right_turn_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['valet_parking_config'])
_SCENARIOCONFIG.fields_by_name['valet_parking_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_SCENARIOCONFIG.oneofs_by_name['scenario_config'].fields.append(
  _SCENARIOCONFIG.fields_by_name['yield_sign_config'])
_SCENARIOCONFIG.fields_by_name['yield_sign_config'].containing_oneof = _SCENARIOCONFIG.oneofs_by_name['scenario_config']
_PLANNERNAVICONFIG.fields_by_name['task'].enum_type = _TASKCONFIG_TASKTYPE
_PLANNERNAVICONFIG.fields_by_name['navi_path_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._NAVIPATHDECIDERCONFIG
_PLANNERNAVICONFIG.fields_by_name['navi_speed_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._NAVISPEEDDECIDERCONFIG
_PLANNERNAVICONFIG.fields_by_name['navi_obstacle_decider_config'].message_type = modules_dot_planning_dot_proto_dot_task__config__pb2._NAVIOBSTACLEDECIDERCONFIG
_RTKPLANNINGCONFIG.fields_by_name['planner_type'].enum_type = _PLANNERTYPE
_STANDARDPLANNINGCONFIG.fields_by_name['planner_type'].enum_type = _PLANNERTYPE
_STANDARDPLANNINGCONFIG.fields_by_name['planner_public_road_config'].message_type = _PLANNERPUBLICROADCONFIG
_NAVIGATIONPLANNINGCONFIG.fields_by_name['planner_type'].enum_type = _PLANNERTYPE
_NAVIGATIONPLANNINGCONFIG.fields_by_name['planner_navi_config'].message_type = _PLANNERNAVICONFIG
_PLANNINGCONFIG.fields_by_name['topic_config'].message_type = _TOPICCONFIG
_PLANNINGCONFIG.fields_by_name['learning_mode'].enum_type = _PLANNINGCONFIG_PLANNINGLEARNINGMODE
_PLANNINGCONFIG.fields_by_name['rtk_planning_config'].message_type = _RTKPLANNINGCONFIG
_PLANNINGCONFIG.fields_by_name['standard_planning_config'].message_type = _STANDARDPLANNINGCONFIG
_PLANNINGCONFIG.fields_by_name['navigation_planning_config'].message_type = _NAVIGATIONPLANNINGCONFIG
_PLANNINGCONFIG.fields_by_name['default_task_config'].message_type = _TASKCONFIG
_PLANNINGCONFIG_PLANNINGLEARNINGMODE.containing_type = _PLANNINGCONFIG
_PLANNINGCONFIG.oneofs_by_name['planning_config'].fields.append(
  _PLANNINGCONFIG.fields_by_name['rtk_planning_config'])
_PLANNINGCONFIG.fields_by_name['rtk_planning_config'].containing_oneof = _PLANNINGCONFIG.oneofs_by_name['planning_config']
_PLANNINGCONFIG.oneofs_by_name['planning_config'].fields.append(
  _PLANNINGCONFIG.fields_by_name['standard_planning_config'])
_PLANNINGCONFIG.fields_by_name['standard_planning_config'].containing_oneof = _PLANNINGCONFIG.oneofs_by_name['planning_config']
_PLANNINGCONFIG.oneofs_by_name['planning_config'].fields.append(
  _PLANNINGCONFIG.fields_by_name['navigation_planning_config'])
_PLANNINGCONFIG.fields_by_name['navigation_planning_config'].containing_oneof = _PLANNINGCONFIG.oneofs_by_name['planning_config']
DESCRIPTOR.message_types_by_name['TaskConfig'] = _TASKCONFIG
DESCRIPTOR.message_types_by_name['ScenarioBareIntersectionUnprotectedConfig'] = _SCENARIOBAREINTERSECTIONUNPROTECTEDCONFIG
DESCRIPTOR.message_types_by_name['ScenarioEmergencyPullOverConfig'] = _SCENARIOEMERGENCYPULLOVERCONFIG
DESCRIPTOR.message_types_by_name['ScenarioEmergencyStopConfig'] = _SCENARIOEMERGENCYSTOPCONFIG
DESCRIPTOR.message_types_by_name['ScenarioLaneFollowConfig'] = _SCENARIOLANEFOLLOWCONFIG
DESCRIPTOR.message_types_by_name['ScenarioLearningModelSampleConfig'] = _SCENARIOLEARNINGMODELSAMPLECONFIG
DESCRIPTOR.message_types_by_name['ScenarioNarrowStreetUTurnConfig'] = _SCENARIONARROWSTREETUTURNCONFIG
DESCRIPTOR.message_types_by_name['ScenarioParkAndGoConfig'] = _SCENARIOPARKANDGOCONFIG
DESCRIPTOR.message_types_by_name['ScenarioPullOverConfig'] = _SCENARIOPULLOVERCONFIG
DESCRIPTOR.message_types_by_name['ScenarioStopSignUnprotectedConfig'] = _SCENARIOSTOPSIGNUNPROTECTEDCONFIG
DESCRIPTOR.message_types_by_name['ScenarioTrafficLightProtectedConfig'] = _SCENARIOTRAFFICLIGHTPROTECTEDCONFIG
DESCRIPTOR.message_types_by_name['ScenarioTrafficLightUnprotectedLeftTurnConfig'] = _SCENARIOTRAFFICLIGHTUNPROTECTEDLEFTTURNCONFIG
DESCRIPTOR.message_types_by_name['ScenarioTrafficLightUnprotectedRightTurnConfig'] = _SCENARIOTRAFFICLIGHTUNPROTECTEDRIGHTTURNCONFIG
DESCRIPTOR.message_types_by_name['ScenarioValetParkingConfig'] = _SCENARIOVALETPARKINGCONFIG
DESCRIPTOR.message_types_by_name['ScenarioYieldSignConfig'] = _SCENARIOYIELDSIGNCONFIG
DESCRIPTOR.message_types_by_name['ScenarioConfig'] = _SCENARIOCONFIG
DESCRIPTOR.message_types_by_name['PlannerPublicRoadConfig'] = _PLANNERPUBLICROADCONFIG
DESCRIPTOR.message_types_by_name['PlannerNaviConfig'] = _PLANNERNAVICONFIG
DESCRIPTOR.message_types_by_name['RtkPlanningConfig'] = _RTKPLANNINGCONFIG
DESCRIPTOR.message_types_by_name['StandardPlanningConfig'] = _STANDARDPLANNINGCONFIG
DESCRIPTOR.message_types_by_name['NavigationPlanningConfig'] = _NAVIGATIONPLANNINGCONFIG
DESCRIPTOR.message_types_by_name['TopicConfig'] = _TOPICCONFIG
DESCRIPTOR.message_types_by_name['PlanningConfig'] = _PLANNINGCONFIG
DESCRIPTOR.enum_types_by_name['PlannerType'] = _PLANNERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TaskConfig = _reflection.GeneratedProtocolMessageType('TaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _TASKCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TaskConfig)
  })
_sym_db.RegisterMessage(TaskConfig)

ScenarioBareIntersectionUnprotectedConfig = _reflection.GeneratedProtocolMessageType('ScenarioBareIntersectionUnprotectedConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOBAREINTERSECTIONUNPROTECTEDCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioBareIntersectionUnprotectedConfig)
  })
_sym_db.RegisterMessage(ScenarioBareIntersectionUnprotectedConfig)

ScenarioEmergencyPullOverConfig = _reflection.GeneratedProtocolMessageType('ScenarioEmergencyPullOverConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOEMERGENCYPULLOVERCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioEmergencyPullOverConfig)
  })
_sym_db.RegisterMessage(ScenarioEmergencyPullOverConfig)

ScenarioEmergencyStopConfig = _reflection.GeneratedProtocolMessageType('ScenarioEmergencyStopConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOEMERGENCYSTOPCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioEmergencyStopConfig)
  })
_sym_db.RegisterMessage(ScenarioEmergencyStopConfig)

ScenarioLaneFollowConfig = _reflection.GeneratedProtocolMessageType('ScenarioLaneFollowConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOLANEFOLLOWCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioLaneFollowConfig)
  })
_sym_db.RegisterMessage(ScenarioLaneFollowConfig)

ScenarioLearningModelSampleConfig = _reflection.GeneratedProtocolMessageType('ScenarioLearningModelSampleConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOLEARNINGMODELSAMPLECONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioLearningModelSampleConfig)
  })
_sym_db.RegisterMessage(ScenarioLearningModelSampleConfig)

ScenarioNarrowStreetUTurnConfig = _reflection.GeneratedProtocolMessageType('ScenarioNarrowStreetUTurnConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIONARROWSTREETUTURNCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioNarrowStreetUTurnConfig)
  })
_sym_db.RegisterMessage(ScenarioNarrowStreetUTurnConfig)

ScenarioParkAndGoConfig = _reflection.GeneratedProtocolMessageType('ScenarioParkAndGoConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOPARKANDGOCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioParkAndGoConfig)
  })
_sym_db.RegisterMessage(ScenarioParkAndGoConfig)

ScenarioPullOverConfig = _reflection.GeneratedProtocolMessageType('ScenarioPullOverConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOPULLOVERCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioPullOverConfig)
  })
_sym_db.RegisterMessage(ScenarioPullOverConfig)

ScenarioStopSignUnprotectedConfig = _reflection.GeneratedProtocolMessageType('ScenarioStopSignUnprotectedConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOSTOPSIGNUNPROTECTEDCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioStopSignUnprotectedConfig)
  })
_sym_db.RegisterMessage(ScenarioStopSignUnprotectedConfig)

ScenarioTrafficLightProtectedConfig = _reflection.GeneratedProtocolMessageType('ScenarioTrafficLightProtectedConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOTRAFFICLIGHTPROTECTEDCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioTrafficLightProtectedConfig)
  })
_sym_db.RegisterMessage(ScenarioTrafficLightProtectedConfig)

ScenarioTrafficLightUnprotectedLeftTurnConfig = _reflection.GeneratedProtocolMessageType('ScenarioTrafficLightUnprotectedLeftTurnConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOTRAFFICLIGHTUNPROTECTEDLEFTTURNCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioTrafficLightUnprotectedLeftTurnConfig)
  })
_sym_db.RegisterMessage(ScenarioTrafficLightUnprotectedLeftTurnConfig)

ScenarioTrafficLightUnprotectedRightTurnConfig = _reflection.GeneratedProtocolMessageType('ScenarioTrafficLightUnprotectedRightTurnConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOTRAFFICLIGHTUNPROTECTEDRIGHTTURNCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioTrafficLightUnprotectedRightTurnConfig)
  })
_sym_db.RegisterMessage(ScenarioTrafficLightUnprotectedRightTurnConfig)

ScenarioValetParkingConfig = _reflection.GeneratedProtocolMessageType('ScenarioValetParkingConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOVALETPARKINGCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioValetParkingConfig)
  })
_sym_db.RegisterMessage(ScenarioValetParkingConfig)

ScenarioYieldSignConfig = _reflection.GeneratedProtocolMessageType('ScenarioYieldSignConfig', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOYIELDSIGNCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioYieldSignConfig)
  })
_sym_db.RegisterMessage(ScenarioYieldSignConfig)

ScenarioConfig = _reflection.GeneratedProtocolMessageType('ScenarioConfig', (_message.Message,), {

  'StageConfig' : _reflection.GeneratedProtocolMessageType('StageConfig', (_message.Message,), {
    'DESCRIPTOR' : _SCENARIOCONFIG_STAGECONFIG,
    '__module__' : 'modules.planning.proto.planning_config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioConfig.StageConfig)
    })
  ,
  'DESCRIPTOR' : _SCENARIOCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ScenarioConfig)
  })
_sym_db.RegisterMessage(ScenarioConfig)
_sym_db.RegisterMessage(ScenarioConfig.StageConfig)

PlannerPublicRoadConfig = _reflection.GeneratedProtocolMessageType('PlannerPublicRoadConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLANNERPUBLICROADCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlannerPublicRoadConfig)
  })
_sym_db.RegisterMessage(PlannerPublicRoadConfig)

PlannerNaviConfig = _reflection.GeneratedProtocolMessageType('PlannerNaviConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLANNERNAVICONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlannerNaviConfig)
  })
_sym_db.RegisterMessage(PlannerNaviConfig)

RtkPlanningConfig = _reflection.GeneratedProtocolMessageType('RtkPlanningConfig', (_message.Message,), {
  'DESCRIPTOR' : _RTKPLANNINGCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.RtkPlanningConfig)
  })
_sym_db.RegisterMessage(RtkPlanningConfig)

StandardPlanningConfig = _reflection.GeneratedProtocolMessageType('StandardPlanningConfig', (_message.Message,), {
  'DESCRIPTOR' : _STANDARDPLANNINGCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.StandardPlanningConfig)
  })
_sym_db.RegisterMessage(StandardPlanningConfig)

NavigationPlanningConfig = _reflection.GeneratedProtocolMessageType('NavigationPlanningConfig', (_message.Message,), {
  'DESCRIPTOR' : _NAVIGATIONPLANNINGCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.NavigationPlanningConfig)
  })
_sym_db.RegisterMessage(NavigationPlanningConfig)

TopicConfig = _reflection.GeneratedProtocolMessageType('TopicConfig', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TopicConfig)
  })
_sym_db.RegisterMessage(TopicConfig)

PlanningConfig = _reflection.GeneratedProtocolMessageType('PlanningConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGCONFIG,
  '__module__' : 'modules.planning.proto.planning_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningConfig)
  })
_sym_db.RegisterMessage(PlanningConfig)


# @@protoc_insertion_point(module_scope)
